﻿using System.Linq;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.ChangeTracking;
using Microsoft.EntityFrameworkCore.Storage.ValueConversion;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Logging.Console;
using Microsoft.Extensions.Logging.Debug;

namespace Publications {
    public class PublicationsContext : DbContext {
        public PublicationsContext (DbContextOptions<PublicationsContext> options) : base (options) { }

        public PublicationsContext () { }
        public DbSet<Magazine> Magazines { get; set; }
      

        public static readonly LoggerFactory DbCommandConsoleLoggerFactory
            = new LoggerFactory (new [] {
                new ConsoleLoggerProvider ((category, level) => category == DbLoggerCategory.Database.Command.Name &&
                    level == LogLevel.Debug, true)
            });
        public static readonly LoggerFactory DbCommandConsoleLoggerFactory2
           = new LoggerFactory(new[] {
                new ConsoleLoggerProvider ((category, level) => category == DbLoggerCategory.Database.Command.Name, true)
           });

        public static readonly LoggerFactory EverythingConsoleLoggerFactory
           = new LoggerFactory(new[] {
                new ConsoleLoggerProvider ((category, level) => true, false)
           });
       

        public static readonly LoggerFactory ChangeTrackingConsoleLoggerFactory
            = new LoggerFactory (new [] {
                new ConsoleLoggerProvider ((category, level) => category == DbLoggerCategory.ChangeTracking.Name ,true)
            });
        public static readonly LoggerFactory ChangeTrackingAndSqlConsoleLoggerFactory
           = new LoggerFactory(new[] {
                new ConsoleLoggerProvider (
                    (category, level) => 
                    (category == DbLoggerCategory.ChangeTracking.Name | category==DbLoggerCategory.Database.Command.Name) 
                    && level==LogLevel.Debug ,true)
           });

        public static readonly LoggerFactory DbCommandDebugLoggerFactory
            = new LoggerFactory (new [] {
                new DebugLoggerProvider((category, level) => category == DbLoggerCategory.Database.Command.Name &&
                    level == LogLevel.Information)
            });


        protected override void OnConfiguring (DbContextOptionsBuilder optionsBuilder) {
            if (!optionsBuilder.IsConfigured) {
                optionsBuilder.UseSqlite (@"Filename=d:\data\PubsTracker.db");
                //optionsBuilder.UseSqlServer("Server=localhost;Database=Pubs;User Id=sa;Password=Passw0rd;");
            }
            optionsBuilder
                .UseLoggerFactory (ChangeTrackingAndSqlConsoleLoggerFactory).EnableSensitiveDataLogging();

        }

        protected override void OnModelCreating (ModelBuilder modelBuilder) {

        
        }
    }
}